@@ -105,7 +105,7 @@ def _parse_date_part(self: parser.Parser) -> t.Optional[exp.Expression]:
             scale = None
 
         ts = self.expression(exp.Cast, this=expression, to=exp.DataType.build("TIMESTAMP"))
-        to_unix = self.expression(exp.TimeToUnix, this=ts)
+        to_unix: exp.Expression = self.expression(exp.TimeToUnix, this=ts)
 
         if scale:
             to_unix = exp.Mul(this=to_unix, expression=exp.Literal.number(scale))
@@ -272,9 +272,13 @@ class Snowflake(Dialect):
             "$": TokenType.PARAMETER,
         }
 
+        VAR_SINGLE_TOKENS = {"$"}
+
     class Generator(generator.Generator):
         PARAMETER_TOKEN = "$"
         MATCHED_BY_SOURCE = False
+        SINGLE_STRING_INTERVAL = True
+        WITH_JOIN_HINT = False
 
         TRANSFORMS = {
             **generator.Generator.TRANSFORMS,  # type: ignore
@@ -328,6 +332,7 @@ class Snowflake(Dialect):
         PROPERTIES_LOCATION = {
             **generator.Generator.PROPERTIES_LOCATION,  # type: ignore
             exp.SetProperty: exp.Properties.Location.UNSUPPORTED,
+            exp.VolatileProperty: exp.Properties.Location.UNSUPPORTED,
         }
 
         def except_op(self, expression: exp.Except) -> str:
