@@ -16,7 +16,7 @@ from sqlglot.tokens import TokenType
 
 def _date_add_sql(self, expression):
     modifier = expression.expression
-    modifier = expression.name if modifier.is_string else self.sql(modifier)
+    modifier = modifier.name if modifier.is_string else self.sql(modifier)
     unit = expression.args.get("unit")
     modifier = f"'{modifier} {unit.name}'" if unit else f"'{modifier}'"
     return self.func("DATE", expression.this, modifier)
@@ -38,6 +38,8 @@ class SQLite(Dialect):
         }
 
     class Generator(generator.Generator):
+        WITH_JOIN_HINT = False
+
         TYPE_MAPPING = {
             **generator.Generator.TYPE_MAPPING,  # type: ignore
             exp.DataType.Type.BOOLEAN: "INTEGER",
@@ -82,6 +84,11 @@ class SQLite(Dialect):
             exp.TryCast: no_trycast_sql,
         }
 
+        PROPERTIES_LOCATION = {
+            **generator.Generator.PROPERTIES_LOCATION,  # type: ignore
+            exp.VolatileProperty: exp.Properties.Location.UNSUPPORTED,
+        }
+
         LIMIT_FETCH = "LIMIT"
 
         def cast_sql(self, expression: exp.Cast) -> str:
